@@ -2,7 +2,7 @@
  * http.c: HTTP input module
  *****************************************************************************
  * Copyright (C) 2001-2008 VLC authors and VideoLAN
- * $Id: f5b4eacbd15e5313a5d56bde1c06d5f816d819d1 $
+ * $Id: 1d58a034b899673c03cdab3af990c64a22be8afe $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Christophe Massiot <massiot@via.ecp.fr>
@@ -408,61 +408,54 @@ static int ReadICYMeta( stream_t *p_access );
 static ssize_t Read( stream_t *p_access, void *p_buffer, size_t i_len )
 {
     access_sys_t *p_sys = p_access->p_sys;
-    int i_total_read = 0;
-    int i_remain_toread = i_len;
 
     if( p_sys->fd == -1 )
         return 0;
 
-    while( i_remain_toread > 0 )
+    int i_chunk = i_len;
+
+    if( p_sys->i_icy_meta > 0 )
     {
-        int i_chunk = i_remain_toread;
+        if( UINT64_MAX - i_chunk < p_sys->offset )
+            i_chunk = UINT64_MAX - p_sys->offset;
 
-        if( p_sys->i_icy_meta > 0 )
-        {
-            if( UINT64_MAX - i_chunk < p_sys->offset )
-                i_chunk = i_remain_toread = UINT64_MAX - p_sys->offset;
-
-            if( p_sys->offset + i_chunk > p_sys->i_icy_offset )
-                i_chunk = p_sys->i_icy_offset - p_sys->offset;
-        }
-
-        int i_read = 0;
-        if( ReadData( p_access, &i_read, &((uint8_t*)p_buffer)[i_total_read], i_chunk ) )
-            return 0;
-
-        if( i_read < 0 )
-            return -1; /* EINTR / EAGAIN */
-
-        if( i_read == 0 )
-        {
-            Disconnect( p_access );
-            if( p_sys->b_reconnect )
-            {
-                msg_Dbg( p_access, "got disconnected, trying to reconnect" );
-                if( Connect( p_access ) )
-                    msg_Dbg( p_access, "reconnection failed" );
-                else
-                    return -1;
-            }
-            return 0;
-        }
-
-        assert( i_read >= 0 );
-        p_sys->offset += i_read;
-        i_total_read += i_read;
-        i_remain_toread -= i_read;
-
-        if( p_sys->i_icy_meta > 0 &&
-            p_sys->offset == p_sys->i_icy_offset )
-        {
-            if( ReadICYMeta( p_access ) )
-                return 0;
-            p_sys->i_icy_offset = p_sys->offset + p_sys->i_icy_meta;
-        }
+        if( p_sys->offset + i_chunk > p_sys->i_icy_offset )
+            i_chunk = p_sys->i_icy_offset - p_sys->offset;
     }
 
-    return i_total_read;
+    int i_read = 0;
+    if( ReadData( p_access, &i_read, (uint8_t*)p_buffer, i_chunk ) )
+        return 0;
+
+    if( i_read < 0 )
+        return -1; /* EINTR / EAGAIN */
+
+    if( i_read == 0 )
+    {
+        Disconnect( p_access );
+        if( p_sys->b_reconnect )
+        {
+            msg_Dbg( p_access, "got disconnected, trying to reconnect" );
+            if( Connect( p_access ) )
+                msg_Dbg( p_access, "reconnection failed" );
+            else
+                return -1;
+        }
+        return 0;
+    }
+
+    assert( i_read >= 0 );
+    p_sys->offset += i_read;
+
+    if( p_sys->i_icy_meta > 0 &&
+        p_sys->offset == p_sys->i_icy_offset )
+    {
+        if( ReadICYMeta( p_access ) )
+            return 0;
+        p_sys->i_icy_offset = p_sys->offset + p_sys->i_icy_meta;
+    }
+
+    return i_read;
 }
 
 static int ReadICYMeta( stream_t *p_access )
