@@ -2,7 +2,7 @@
  * svcdsub.c : Overlay Graphics Text (SVCD subtitles) decoder
  *****************************************************************************
  * Copyright (C) 2003, 2004 VLC authors and VideoLAN
- * $Id: df332093648e58d3b0fcc4aadfddb4d57bc0de64 $
+ * $Id: e509effdbce524b8854874365d8b62d6f8f4d58e $
  *
  * Authors: Rocky Bernstein
  *          Gildas Bazin <gbazin@videolan.org>
@@ -48,10 +48,10 @@ vlc_module_begin ()
     set_shortname( N_("SVCD subtitles") )
     set_category( CAT_INPUT )
     set_subcategory( SUBCAT_INPUT_SCODEC )
-    set_capability( "decoder", 50 )
+    set_capability( "spu decoder", 50 )
     set_callbacks( DecoderOpen, DecoderClose )
 
-    add_obsolete_integer ( MODULE_STRING "-debug" )
+    add_obsolete_integer ( "svcdsub-debug" )
 
     add_submodule ()
     set_description( N_("Philips OGT (SVCD subtitle) packetizer") )
@@ -62,17 +62,16 @@ vlc_module_end ()
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
-static subpicture_t *Decode( decoder_t *, block_t ** );
+static int      Decode( decoder_t *, block_t * );
 static block_t *Packetize  ( decoder_t *, block_t ** );
 static block_t *Reassemble ( decoder_t *, block_t * );
 static void ParseHeader( decoder_t *, block_t * );
 static subpicture_t *DecodePacket( decoder_t *, block_t * );
 static void SVCDSubRenderImage( decoder_t *, block_t *, subpicture_region_t * );
 
-#define GETINT16(p) ( (p[0] <<  8) +   p[1] )  ; p +=2;
+#define GETINT16(p) GetWBE(p)  ; p +=2;
 
-#define GETINT32(p) ( (p[0] << 24) +  (p[1] << 16) +    \
-                      (p[2] <<  8) +  (p[3]) ) ; p += 4;
+#define GETINT32(p) GetDWBE(p) ; p += 4;
 
 typedef enum  {
   SUBTITLE_BLOCK_EMPTY    = 0,
@@ -130,10 +129,10 @@ static int DecoderOpen( vlc_object_t *p_this )
     p_sys->i_state = SUBTITLE_BLOCK_EMPTY;
     p_sys->p_spu   = NULL;
 
-    es_format_Init( &p_dec->fmt_out, SPU_ES, VLC_CODEC_OGT );
+    p_dec->fmt_out.i_codec = VLC_CODEC_OGT;
 
-    p_dec->pf_decode_sub = Decode;
-    p_dec->pf_packetize  = Packetize;
+    p_dec->pf_decode    = Decode;
+    p_dec->pf_packetize = Packetize;
 
     return VLC_SUCCESS;
 }
@@ -163,23 +162,23 @@ void DecoderClose( vlc_object_t *p_this )
 /*****************************************************************************
  * Decode:
  *****************************************************************************/
-static subpicture_t *Decode( decoder_t *p_dec, block_t **pp_block )
+static int Decode( decoder_t *p_dec, block_t *p_block )
 {
-    block_t *p_block, *p_spu;
-
 #ifndef NDEBUG
     msg_Dbg( p_dec, "Decode" );
 #endif
 
-    if( pp_block == NULL || *pp_block == NULL ) return NULL;
+    if( p_block == NULL ) /* No Drain */
+        return VLCDEC_SUCCESS;
 
-    p_block = *pp_block;
-    *pp_block = NULL;
-
-    if( !(p_spu = Reassemble( p_dec, p_block )) ) return NULL;
+    if( !(p_block = Reassemble( p_dec, p_block )) )
+        return VLCDEC_SUCCESS;
 
     /* Parse and decode */
-    return DecodePacket( p_dec, p_spu );
+    subpicture_t *p_spu = DecodePacket( p_dec, p_block );
+    if( p_spu != NULL )
+        decoder_QueueSub( p_dec, p_spu );
+    return VLCDEC_SUCCESS;
 }
 
 /*****************************************************************************
@@ -303,6 +302,16 @@ static block_t *Reassemble( decoder_t *p_dec, block_t *p_block )
     {
         block_t *p_spu = block_ChainGather( p_sys->p_spu );
 
+        if( unlikely( !p_spu ) )
+        {
+            block_ChainRelease( p_sys->p_spu );
+            p_sys->i_state = SUBTITLE_BLOCK_EMPTY;
+            p_sys->p_spu = NULL;
+
+            msg_Warn( p_dec, "unable to assemble blocks, discarding" );
+            return NULL;
+        }
+
         if( p_spu->i_buffer != p_sys->i_spu_size )
         {
             msg_Warn( p_dec, "subtitle packets size=%zu should be %zu",
@@ -312,7 +321,7 @@ static block_t *Reassemble( decoder_t *p_dec, block_t *p_block )
         msg_Dbg( p_dec, "subtitle packet complete, size=%zu", p_spu->i_buffer );
 
         p_sys->i_state = SUBTITLE_BLOCK_EMPTY;
-        p_sys->p_spu = 0;
+        p_sys->p_spu = NULL;
         return p_spu;
     }
 
@@ -321,7 +330,7 @@ static block_t *Reassemble( decoder_t *p_dec, block_t *p_block )
 
 /******************************************************************************
   The format is roughly as follows (everything is big-endian):
- 
+
    size     description
    -------------------------------------------
    byte     subtitle channel (0..7) in bits 0-3
@@ -353,12 +362,13 @@ static void ParseHeader( decoder_t *p_dec, block_t *p_block )
 {
     decoder_sys_t *p_sys = p_dec->p_sys;
     uint8_t *p = p_block->p_buffer;
-    uint8_t i_options, i_options2, i_cmd, i_cmd_arg;
+    uint8_t i_options, i_cmd;
     int i;
 
     p_sys->i_spu_size = GETINT16(p);
     i_options  = *p++;
-    i_options2 = *p++;
+    // Skip over unused value
+    p++;
 
     if( i_options & 0x08 ) { p_sys->i_duration = GETINT32(p); }
     else p_sys->i_duration = 0; /* Ephemer subtitle */
@@ -379,7 +389,7 @@ static void ParseHeader( decoder_t *p_dec, block_t *p_block )
 
     i_cmd = *p++;
     /* We do not really know this, FIXME */
-    if( i_cmd ) {i_cmd_arg = GETINT32(p);}
+    if( i_cmd ) { p += 4; }
 
     /* Actually, this is measured against a different origin, so we have to
      * adjust it */
@@ -429,8 +439,7 @@ static subpicture_t *DecodePacket( decoder_t *p_dec, block_t *p_data )
     p_spu->b_ephemer = true;
 
     /* Create new subtitle region */
-    memset( &fmt, 0, sizeof(video_format_t) );
-    fmt.i_chroma = VLC_CODEC_YUVP;
+    video_format_Init( &fmt, VLC_CODEC_YUVP );
 
     /**
        The video on which the subtitle sits, is scaled, probably
@@ -457,6 +466,8 @@ static subpicture_t *DecodePacket( decoder_t *p_dec, block_t *p_data )
     }
 
     p_region = subpicture_region_New( &fmt );
+    fmt.p_palette = NULL;
+    video_format_Clean( &fmt );
     if( !p_region )
     {
         msg_Err( p_dec, "cannot allocate SVCD subtitle region" );
