@@ -2,7 +2,7 @@
  * copy.c: Fast YV12/NV12 copy
  *****************************************************************************
  * Copyright (C) 2010 Laurent Aimar
- * $Id: 8547a6b1f793fb5d3906ddb52c8161e0b4fe5a12 $
+ * $Id: 2baf076d535a65f790b728c7ead160c97bb992fe $
  *
  * Authors: Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
  *          Victorien Le Couviour--Tuffet <victorien.lecouviour.tuffet@gmail.com>
@@ -469,17 +469,18 @@ static void SSE_CopyPlane(uint8_t *dst, size_t dst_pitch,
     const size_t copy_pitch = __MIN(src_pitch, dst_pitch);
     const unsigned w16 = (copy_pitch+15) & ~15;
     const unsigned hstep = cache_size / w16;
+    const unsigned cache_width = __MIN(src_pitch, hstep);
     assert(hstep > 0);
 
     /* If SSE4.1: CopyFromUswc is faster than memcpy */
     if (!vlc_CPU_SSE4_1() && bitshift == 0 && src_pitch == dst_pitch)
-        memcpy(dst, src, src_pitch * height);
+        memcpy(dst, src, copy_pitch * height);
     else
     for (unsigned y = 0; y < height; y += hstep) {
         const unsigned hblock =  __MIN(hstep, height - y);
 
         /* Copy a bunch of line into our cache */
-        CopyFromUswc(cache, w16, src, src_pitch, src_pitch, hblock, bitshift);
+        CopyFromUswc(cache, w16, src, src_pitch, cache_width, hblock, bitshift);
 
         /* Copy from our cache to the destination */
         Copy2d(dst, dst_pitch, cache, w16, copy_pitch, hblock);
@@ -498,8 +499,11 @@ SSE_InterleavePlanes(uint8_t *dst, size_t dst_pitch,
                      unsigned int height, uint8_t pixel_size, int bitshift)
 {
     assert(srcu_pitch == srcv_pitch);
+    size_t copy_pitch = __MIN(dst_pitch / 2, srcu_pitch);
     unsigned int const  w16 = (srcu_pitch+15) & ~15;
     unsigned int const  hstep = (cache_size) / (2*w16);
+    const unsigned cacheu_width = __MIN(srcu_pitch, hstep);
+    const unsigned cachev_width = __MIN(srcv_pitch, hstep);
     assert(hstep > 0);
 
     for (unsigned int y = 0; y < height; y += hstep)
@@ -507,14 +511,14 @@ SSE_InterleavePlanes(uint8_t *dst, size_t dst_pitch,
         unsigned int const      hblock = __MIN(hstep, height - y);
 
         /* Copy a bunch of line into our cache */
-        CopyFromUswc(cache, w16, srcu, srcu_pitch, srcu_pitch, hblock, bitshift);
+        CopyFromUswc(cache, w16, srcu, srcu_pitch, cacheu_width, hblock, bitshift);
         CopyFromUswc(cache+w16*hblock, w16, srcv, srcv_pitch,
-                     srcv_pitch, hblock, bitshift);
+                     cachev_width, hblock, bitshift);
 
         /* Copy from our cache to the destination */
         SSE_InterleaveUV(dst, dst_pitch, cache, w16,
                          cache + w16 * hblock, w16,
-                         srcu_pitch, hblock, pixel_size);
+                         copy_pitch, hblock, pixel_size);
 
         /* */
         srcu += hblock * srcu_pitch;
@@ -529,19 +533,21 @@ static void SSE_SplitPlanes(uint8_t *dstu, size_t dstu_pitch,
                             uint8_t *cache, size_t cache_size,
                             unsigned height, uint8_t pixel_size, int bitshift)
 {
+    size_t copy_pitch = __MIN(__MIN(src_pitch / 2, dstu_pitch), dstv_pitch);
     const unsigned w16 = (src_pitch+15) & ~15;
     const unsigned hstep = cache_size / w16;
+    const unsigned cache_width = __MIN(src_pitch, hstep);
     assert(hstep > 0);
 
     for (unsigned y = 0; y < height; y += hstep) {
         const unsigned hblock =  __MIN(hstep, height - y);
 
         /* Copy a bunch of line into our cache */
-        CopyFromUswc(cache, w16, src, src_pitch, src_pitch, hblock, bitshift);
+        CopyFromUswc(cache, w16, src, src_pitch, cache_width, hblock, bitshift);
 
         /* Copy from our cache to the destination */
         SSE_SplitUV(dstu, dstu_pitch, dstv, dstv_pitch,
-                    cache, w16, src_pitch / 2, hblock, pixel_size);
+                    cache, w16, copy_pitch, hblock, pixel_size);
 
         /* */
         src  += src_pitch  * hblock;
@@ -676,8 +682,9 @@ void Copy420_SP_to_SP(picture_t *dst, const uint8_t *src[static 2],
 }
 
 #define SPLIT_PLANES(type, pitch_den) do { \
+    size_t copy_pitch = __MIN(__MIN(src_pitch / pitch_den, dstu_pitch), dstv_pitch); \
     for (unsigned y = 0; y < height; y++) { \
-        for (unsigned x = 0; x < src_pitch / pitch_den; x++) { \
+        for (unsigned x = 0; x < copy_pitch; x++) { \
             ((type *) dstu)[x] = ((const type *) src)[2*x+0]; \
             ((type *) dstv)[x] = ((const type *) src)[2*x+1]; \
         } \
@@ -688,8 +695,9 @@ void Copy420_SP_to_SP(picture_t *dst, const uint8_t *src[static 2],
 } while(0)
 
 #define SPLIT_PLANES_SHIFTR(type, pitch_den, bitshift) do { \
+    size_t copy_pitch = __MIN(__MIN(src_pitch / pitch_den, dstu_pitch), dstv_pitch); \
     for (unsigned y = 0; y < height; y++) { \
-        for (unsigned x = 0; x < src_pitch / pitch_den; x++) { \
+        for (unsigned x = 0; x < copy_pitch; x++) { \
             ((type *) dstu)[x] = (((const type *) src)[2*x+0]) >> (bitshift); \
             ((type *) dstv)[x] = (((const type *) src)[2*x+1]) >> (bitshift); \
         } \
@@ -700,8 +708,9 @@ void Copy420_SP_to_SP(picture_t *dst, const uint8_t *src[static 2],
 } while(0)
 
 #define SPLIT_PLANES_SHIFTL(type, pitch_den, bitshift) do { \
+    size_t copy_pitch = __MIN(__MIN(src_pitch / pitch_den, dstu_pitch), dstv_pitch); \
     for (unsigned y = 0; y < height; y++) { \
-        for (unsigned x = 0; x < src_pitch / pitch_den; x++) { \
+        for (unsigned x = 0; x < copy_pitch; x++) { \
             ((type *) dstu)[x] = (((const type *) src)[2*x+0]) << (bitshift); \
             ((type *) dstv)[x] = (((const type *) src)[2*x+1]) << (bitshift); \
         } \
@@ -823,7 +832,7 @@ void Copy420_P_to_SP(picture_t *dst, const uint8_t *src[static 3],
               src[0], src_pitch[0], height, 0);
 
     const unsigned copy_lines = (height+1) / 2;
-    const unsigned copy_pitch = src_pitch[1];
+    const unsigned copy_pitch = __MIN(src_pitch[1], dst->p[1].i_pitch / 2);
 
     const int i_extra_pitch_uv = dst->p[1].i_pitch - 2 * copy_pitch;
     const int i_extra_pitch_u  = src_pitch[U_PLANE] - copy_pitch;
