@@ -2,7 +2,7 @@
  * algo_yadif.h : Wrapper for FFmpeg's Yadif algorithm
  *****************************************************************************
  * Copyright (C) 2000-2011 the VideoLAN team
- * $Id: d1ff76f8175c01afe74d1222a9ab671ba32f188f $
+ * $Id: 7bc4518b0e98d3538dbea6b7b8a7e5896faf17f0 $
  *
  * Author: Laurent Aimar <fenrir@videolan.org>
  *         Juha Jeronen  <juha.jeronen@jyu.fi> (soft field repeat hack)
@@ -86,4 +86,9 @@ struct picture_t;
 int RenderYadif( filter_t *p_filter, picture_t *p_dst, picture_t *p_src,
                  int i_order, int i_field );
 
+/**
+ * Same as RenderYadif() but with no temporal references
+ */
+int RenderYadifSingle( filter_t *p_filter, picture_t *p_dst, picture_t *p_src );
+
 #endif
