@@ -1,8 +1,8 @@
 /*****************************************************************************
  * modules.h : Module management functions.
  *****************************************************************************
- * Copyright (C) 2001 VLC authors and VideoLAN
- * $Id: e38e9524c1bf51ed0ac8e6da61759bb169b53b4c $
+ * Copyright (C) 2001-2016 VLC authors and VideoLAN
+ * $Id: 60a36e7d4909412e41cda62952283663d3331fed $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -24,28 +24,50 @@
 #ifndef LIBVLC_MODULES_H
 # define LIBVLC_MODULES_H 1
 
-typedef struct module_cache_t module_cache_t;
+# include <vlc_atomic.h>
 
-/*****************************************************************************
- * Module cache description structure
- *****************************************************************************/
-struct module_cache_t
+/** The plugin handle type */
+typedef void *module_handle_t;
+
+/** VLC plugin */
+typedef struct vlc_plugin_t
 {
-    /* Mandatory cache entry header */
-    char  *path;
-    time_t mtime;
-    off_t  size;
+    struct vlc_plugin_t *next;
+    module_t *module;
+    unsigned modules_count;
 
-    /* Optional extra data */
-    module_t *p_module;
-};
+    const char *textdomain; /**< gettext domain (or NULL) */
 
+    /**
+     * Variables set by the module to store its config options
+     */
+    struct
+    {
+        module_config_t *items; /**< Table of configuration parameters */
+        size_t size; /**< Size of items table */
+        size_t count; /**< Number of configuration items */
+        size_t booleans; /**< Number of booleal config items */
+    } conf;
+
+#ifdef HAVE_DYNAMIC_PLUGINS
+    atomic_bool loaded; /**< Whether the plug-in is mapped in memory */
+    bool unloadable; /**< Whether the plug-in can be unloaded safely */
+    module_handle_t handle; /**< Run-time linker handle (if loaded) */
+    char *abspath; /**< Absolute path */
+
+    char *path; /**< Relative path (within plug-in directory) */
+    int64_t mtime; /**< Last modification time */
+    uint64_t size; /**< File size */
+#endif
+} vlc_plugin_t;
+
+/**
+ * List of all plug-ins.
+ */
+extern struct vlc_plugin_t *vlc_plugins;
 
 #define MODULE_SHORTCUT_MAX 20
 
-/** The module handle type */
-typedef void *module_handle_t;
-
 /** Plugin entry point prototype */
 typedef int (*vlc_plugin_cb) (int (*)(void *, void *, int, ...), void *);
 
@@ -57,58 +79,43 @@ int vlc_entry__core (int (*)(void *, void *, int, ...), void *);
  */
 struct module_t
 {
+    vlc_plugin_t *plugin; /**< Plug-in/library containing the module */
     module_t   *next;
-    module_t   *parent;
-    module_t   *submodule;
-    unsigned    submodule_count;
 
     /** Shortcuts to the module */
     unsigned    i_shortcuts;
-    char        **pp_shortcuts;
+    const char **pp_shortcuts;
 
     /*
      * Variables set by the module to identify itself
      */
-    char *psz_shortname;                              /**< Module name */
-    char *psz_longname;                   /**< Module descriptive name */
-    char *psz_help;        /**< Long help string for "special" modules */
+    const char *psz_shortname;                              /**< Module name */
+    const char *psz_longname;                   /**< Module descriptive name */
+    const char *psz_help;        /**< Long help string for "special" modules */
 
-    char    *psz_capability;                                 /**< Capability */
+    const char *psz_capability;                              /**< Capability */
     int      i_score;                          /**< Score for the capability */
 
-    bool          b_loaded;        /* Set to true if the dll is loaded */
-    bool b_unloadable;                        /**< Can we be dlclosed? */
-
     /* Callbacks */
+    const char *activate_name;
+    const char *deactivate_name;
     void *pf_activate;
     void *pf_deactivate;
-
-    /*
-     * Variables set by the module to store its config options
-     */
-    module_config_t *p_config;             /* Module configuration structure */
-    size_t           confsize;            /* Number of module_config_t items */
-    unsigned int     i_config_items;        /* number of configuration items */
-    unsigned int     i_bool_items;            /* number of bool config items */
-
-    /*
-     * Variables used internally by the module manager
-     */
-    /* Plugin-specific stuff */
-    module_handle_t     handle;                             /* Unique handle */
-    char *              psz_filename;                     /* Module filename */
-    char *              domain;                            /* gettext domain */
 };
 
-module_t *vlc_plugin_describe (vlc_plugin_cb);
-module_t *vlc_module_create (module_t *);
+vlc_plugin_t *vlc_plugin_create(void);
+void vlc_plugin_destroy(vlc_plugin_t *);
+module_t *vlc_module_create(vlc_plugin_t *);
 void vlc_module_destroy (module_t *);
 
+vlc_plugin_t *vlc_plugin_describe(vlc_plugin_cb);
+int vlc_plugin_resolve(vlc_plugin_t *, vlc_plugin_cb);
+
 void module_InitBank (void);
 size_t module_LoadPlugins( vlc_object_t * );
 #define module_LoadPlugins(a) module_LoadPlugins(VLC_OBJECT(a))
 void module_EndBank (bool);
-int module_Map (vlc_object_t *, module_t *);
+int module_Map(vlc_object_t *, vlc_plugin_t *);
 
 ssize_t module_list_cap (module_t ***, const char *);
 
@@ -120,16 +127,9 @@ void *module_Lookup (module_handle_t, const char *);
 void module_Unload (module_handle_t);
 
 /* Plugins cache */
-void   CacheMerge (vlc_object_t *, module_t *, module_t *);
-void   CacheDelete(vlc_object_t *, const char *);
-size_t CacheLoad  (vlc_object_t *, const char *, module_cache_t **);
+vlc_plugin_t *vlc_cache_load(vlc_object_t *, const char *, block_t **);
+vlc_plugin_t *vlc_cache_lookup(vlc_plugin_t **, const char *relpath);
 
-struct stat;
-
-int CacheAdd (module_cache_t **, size_t *,
-              const char *, const struct stat *, module_t *);
-void CacheSave  (vlc_object_t *, const char *, module_cache_t *, size_t);
-module_t *CacheFind (module_cache_t *, size_t,
-                     const char *, const struct stat *);
+void CacheSave(vlc_object_t *, const char *, vlc_plugin_t *const *, size_t);
 
 #endif /* !LIBVLC_MODULES_H */
